import { Gantt } from './../index';
import { GanttColumnSizeMode, GanttSelectionMode, GanttSortMode, TableColumnGroup, TableColumn, GanttDataSourceSettings } from './../index';
import { AfterViewInit, ElementRef, OnInit, OnChanges, OnDestroy, SimpleChanges, EventEmitter } from '@angular/core';
import { BaseElement } from './smart.element';
export { TableColumnDataType, TableColumnFreeze, GanttColumnSizeMode, GanttDataSourceSettingsSanitizeHTML, GanttDataSourceSettingsDataFieldDataType, GanttDataSourceSettingsDataSourceType, GanttSelectionMode, GanttSortMode, TableColumnGroup, TableColumn, GanttDataSourceSettings, GanttDataSourceSettingsDataField, ElementRenderMode } from './../index';
export { Smart } from './smart.element';
export { Gantt } from './../index';
export declare class GanttComponent extends BaseElement implements OnInit, AfterViewInit, OnDestroy, OnChanges {
    constructor(ref: ElementRef<Gantt>);
    private eventHandlers;
    nativeElement: Gantt;
    /** @description Creates the component on demand.
     * @param properties An optional object of properties, which will be added to the template binded ones.
     */
    createComponent(properties?: {}): any;
    /** @description Sets or gets a list of column groups that constitute the column header hierarchy. Note: when column header hierarchy is created, column resizing and auto-sizing is not supported. */
    columnGroups: TableColumnGroup[];
    /** @description Sets or gets the min width of columns when columnSizeMode is 'auto' or when resizing columns. This property has no effect on columns with programmatically set width. */
    columnMinWidth: string | number;
    /** @description Sets or gets whether the reordering of columns is enabled. */
    columnReorder: boolean;
    /** @description Sets or gets whether the resizing of columns is enabled. Note: column sizes continue to adhere to the behavior of the standard HTML table element's table-layout: fixed, upon which smart-table is based. */
    columnResize: boolean;
    /** @description Sets or gets whether when resizing a column, a feedback showing the new column width in px will be displayed. */
    columnResizeFeedback: boolean;
    /** @description Describes the columns properties. */
    columns: TableColumn[];
    /** @description Sets or gets the column sizing behavior. In 'auto' mode Columns are automatically sized based on their content and the value of the columnMinWidth property, unless there is not enough space in the Table, in which case ellipses are shown. User-set static column width is still respected. In 'default' mode Columns are sized according to the rules of the standard HTML table element's table-layout: fixed. Custom width can also be applied to columns in this case by setting the column width property. */
    columnSizeMode: GanttColumnSizeMode;
    /** @description When binding the dataSource property directly to an array (as opposed to an instance of JQX.DataAdapter), sets or gets the name of the data field in the source array to bind row ids to. */
    dataRowId: string;
    /** @description Determines the data source of the Gantt component. The data source of the Gantt can be a regular Array or a DataAdapter instance. You can read more about the dataAdapter here - https://www.htmlelements.com/docs/data-adapter/. */
    dataSource: any;
    /** @description Sets the grid's data source settings when the dataSource property is set to an Array or URL. */
    dataSourceSettings: GanttDataSourceSettings;
    /** @description Disables the interaction with the element. */
    dataTransform: {
        (record: any): void;
    };
    /** @description Sets or gets whether the Gantt can be filtered. By default, the Gantt can be filtered by all string and numeric columns through a filter input in the header. */
    disabled: boolean;
    /** @description Sets or gets whether the Gantt can be filtered via a filter row. */
    filtering: boolean;
    /** @description Sets or gets the id of an HTML template element to be applied as a custom filter template. */
    filterRow: boolean;
    /** @description Sets or gets the id of an HTML template element to be applied as footer row(s). */
    filterTemplate: string;
    /** @description Sets or gets whether the Gantt's footer is sticky/frozen. */
    footerRow: string;
    /** @description Sets or gets whether the Gantt's column header is sticky/frozen. */
    freezeFooter: boolean;
    /** @description Sets or gets the id of an HTML template element to be applied as additional column header(s). */
    freezeHeader: boolean;
    /** @description Sets or gets whether navigation with the keyboard is enabled in the Gantt. */
    headerRow: string;
    /** @description Sets or gets the language. Used in conjunction with the property messages.  */
    keyboardNavigation: boolean;
    /** @description Sets or gets an object specifying strings used in the element that can be localized. Used in conjunction with the property locale.  */
    locale: string;
    /** @description Sets or gets the value indicating whether the element is aligned to support locales using right-to-left fonts. */
    messages: any;
    /** @description Sets or gets a string template to be applied as row detail template. Each cell value in the master row can be placed in the detail row by specifying the cell's data field in double curly brackets (e.g. {{price}}. The details can then be displayed by expanding the row by clicking it. */
    onCellRender: {
        (data: any, dataField: string, value: any, cell: HTMLTableCellElement): void;
    };
    /** @description Sets or gets an array of the Gantt's selected row's ids. */
    onColumnRender: {
        (dataField: string, headerCell: HTMLTableCellElement): void;
    };
    /** @description Sets or gets whether row selection (via checkboxes) is enabled. */
    onInit: {
        (): void;
    };
    /** @description Sets or gets the selection mode. Only applicable when selection is enabled. */
    rightToLeft: boolean;
    /** @description Determines the sorting mode of the Gantt. */
    rowDetailTemplate: string;
    /** @description Sets or gets whether when hovering a cell with truncated content, a tooltip with the full content will be shown. */
    selected: any[];
    /** @description undefined */
    selection: boolean;
    /** @description undefined */
    selectionMode: GanttSelectionMode;
    /** @description undefined */
    sort: {
        (dataSource: any, sortColumns: string[], directions: string[], defaultCompareFunctions: {
            (firstRecord: any, secondRecord: any): number;
        }[]): void;
    };
    /** @description undefined */
    sortMode: GanttSortMode;
    /** @description undefined */
    tooltip: boolean;
    /** @description This event is triggered when a cell edit operation has been initiated.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	id, 	dataField, 	row, 	value)
    *   id - The id of the row.
    *   dataField - The data field of the cell's column.
    *   row - The data of the cell's row.
    *   value - The data value of the cell.
    */
    onCellBeginEdit: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a cell has been clicked.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	id, 	dataField, 	row, 	value, 	originalEvent)
    *   id - The cell's row id.
    *   dataField - The data field of the cell's column.
    *   row - The data of the cell's row.
    *   value - The data value of the cell.
    *   originalEvent - The 'click' event object.
    */
    onCellClick: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a cell has been edited.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	id, 	dataField, 	row, 	value)
    *   id - The id of the row.
    *   dataField - The data field of the cell's column.
    *   row - The new data of the cell's row.
    *   value - The data value of the cell.
    */
    onCellEndEdit: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the selection is changed. Within the event handler you can get the selection by using the 'getSelection' method.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	type)
    *   type - The type of action that initiated the selection change. Possible types: 'programmatic', 'interaction', 'remove'.
    */
    onChange: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a row has been collapsed.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	id, 	record)
    *   id - The id of the collapsed row.
    *   record - The data of the collapsed row.
    */
    onCollapse: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a row has been expanded.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	id, 	record)
    *   id - The id of the expanded row.
    *   record - The (aggregated) data of the expanded row.
    */
    onExpand: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a column header cell has been clicked.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	dataField)
    *   dataField - The data field of the cell's column.
    */
    onColumnClick: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a column has been resized via dragging or double-click.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	dataField, 	headerCellElement, 	width)
    *   dataField - The data field of the column.
    *   headerCellElement - The column's header cell HTML element.
    *   width - The new width of the column.
    */
    onColumnResize: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a filtering-related action is made.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	action, 	filters)
    *   action - The filtering action. Possible actions: 'add', 'remove'.
    *   filters - The added filters. Only when action is 'add'.
    */
    onFilter: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a grouping-related action is made.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	action, 	dataField, 	label, 	path)
    *   action - The grouping action. Possible actions: 'add', 'collapse', 'expand', 'remove'.
    *   dataField - The data field of the column whose grouping is modified.
    *   label - The label of the group (only when collapsing/expanding).
    *   path - The group's path (only when collapsing/expanding). The path includes the path to the expanded/collapsed group starting from the root group. The indexes are joined with '.'. This parameter is available when the 'action' is 'expand' or 'collapse'.
    */
    onGroup: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a row edit operation has been initiated (only when editMode is 'row').
    *  @param event. The custom event. 	Custom event was created with: event.detail(	id, 	row)
    *   id - The id of the row.
    *   row - The data of the row.
    */
    onRowBeginEdit: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a row has been edited (only when editMode is 'row').
    *  @param event. The custom event. 	Custom event was created with: event.detail(	id, 	row)
    *   id - The id of the row.
    *   row - The new data of the row.
    */
    onRowEndEdit: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a column header cell has been clicked or sorting is applied programmatically using the Table API.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	columns, 	sortDataFields, 	sortOrders, 	sortDataTypes, 	type)
    *   columns - An array with information about the columns the Gantt has been sorted by.
    *   sortDataFields - An array with information about the data fields the Gantt has been sorted by.
    *   sortOrders - An array with information about the columns sort orders the Gantt has been sorted by.
    *   sortDataTypes - An array with information about the columns data types the Gantt has been sorted by.
    *   type - The type of action that initiated the data sort. Possible types: 'programmatic', 'interaction'
    */
    onSort: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a ticket drag starts.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	data, 	id)
    *   data - An object with ticket's data.
    *   id - The row's id.
    */
    onTicketDragStart: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a ticket drag is canceled. This can happen when the user presses the 'Escape' key.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	data)
    *   data - An object with ticket's data.
    */
    onTicketDragCancel: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a ticket drag ends.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	data)
    *   data - An object with ticket's data.
    */
    onTicketDragEnd: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a ticket is reordered.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	data, 	endData, 	id)
    *   data - An object with ticket's data.
    *   endData - An object with ticket's data where the end user dropped the dragged ticket.
    *   id - The row's id.
    */
    onTicketReorder: EventEmitter<CustomEvent>;
    /** @description Adds a new row. When you invoke the method, pass a JSON object with the row's data.
    * @param {any} data. JSON object with the new row's data. Sample JSON: {firstName: 'Peter', lastName: 'Fuller'}.
    */
    addRow(data: any): void;
    /** @description Adds a filter to a specific column.
    * @param {string} dataField. The column's data field.
    * @param {any} filter. FilterGroup object.
    */
    addFilter(dataField: string, filter: any): void;
    /** @description Begins an edit operation.
    * @param {string | number} row. The id of the row to edit.
    * @param {string} dataField?. The dataField of the cell's column. May be omitted when <strong>editMode</strong> is <em>'row'</em>.
    */
    beginEdit(row: string | number, dataField?: string): void;
    /** @description Begins an update operation. Suspends all table refreshes and renders.
    */
    beginUpdate(): void;
    /** @description Ends the current edit operation and discards changes.
    */
    cancelEdit(): void;
    /** @description Clears applied filters.
    */
    clearFilters(): void;
    /** @description Clears selection.
    */
    clearSelection(): void;
    /** @description Clears the Gantt sorting.
    */
    clearSort(): void;
    /** @description Collapses all row details. Rows that have details defined via the rowDetailTemplate will be collapsed.
    */
    collapseAllRowDetails(): void;
    /** @description Disables a selection of a row. When the 'selection' property is set to 'true', selection is enabled for all rows by default.
    * @param {string | number | (string | number)[]} rowId. The id of the row (or an array of row ids) to select.
    */
    disableSelect(rowId: string | number | (string | number)[]): void;
    /** @description Enables a selection of a row, if it was previously disabled through a 'disableSelect' method call. When the 'selection' property is set to 'true', selection is enabled for all rows by default.
    * @param {string | number | (string | number)[]} rowId. The id of the row (or an array of row ids) to select.
    */
    enableSelect(rowId: string | number | (string | number)[]): void;
    /** @description Ends the current edit operation and saves changes.
    */
    endEdit(): void;
    /** @description Ends an update operation. Resumes all Gantt refreshes and renders. Re-renders the Gantt.
    * @param {boolean} refresh?. Optionally you can pass 'false' in case you need to manually call the 'refresh' method. By default, the Gantt is re-rendered.
    */
    endUpdate(refresh?: boolean): void;
    /** @description Expands all row details. Rows that have details defined via rowDetailTemplate will be expanded.
    */
    expandAllRowDetails(): void;
    /** @description Returns an array of selected row ids.
    * @returns {(string | number)[]}
  */
    getSelection(): Promise<any>;
    /** @description Returns the value of a cell.
    * @param {string | number} row. The id of the cell's row.
    * @param {string} dataField. The dataField of the cell's column.
    * @returns {any}
  */
    getValue(row: any, dataField: any): Promise<any>;
    /** @description Gets a column property.
    * @param {string} columnDataField. Column field name.
    * @param {string} propertyName. Column property name.
    * @returns {any}
  */
    getColumnProperty(columnDataField: any, propertyName: any): Promise<any>;
    /** @description Refreshes the Gantt.
    */
    refresh(): void;
    /** @description Removes filters applied to a specific column.
    * @param {string} dataField. The column's data field.
    */
    removeFilter(dataField: string): void;
    /** @description Removes a row by its id.
    * @param {string | number} row. The id of the cell's row.
    */
    removeRow(row: string | number): void;
    /** @description Selects one or more rows.
    * @param {string | number | (string | number)[]} rowId. The id of the row (or an array of row ids) to select.
    */
    select(rowId: string | number | (string | number)[]): void;
    /** @description Sets the value of a cell.
    * @param {string | number} row. The id of the cell's row.
    * @param {string} dataField. The dataField of the cell's column.
    * @param {any} value. The new value of the cell.
    */
    setValue(row: string | number, dataField: string, value: any): void;
    /** @description Sorts the Gantt by a column.
    * @param {string} columnDataField. Column field name.
    * @param {string} sortOrder?. Sort order. Possible values: 'asc' (ascending), 'desc' (descending), and null (removes sorting by column). If not provided, toggles the sorting.
    */
    sortBy(columnDataField: string, sortOrder?: string): void;
    /** @description Sets a column property.
    * @param {string} columnDataField. Column field name.
    * @param {string} propertyName. Column property name.
    * @param {any} propertyValue. Property value.
    */
    setColumnProperty(columnDataField: string, propertyName: string, propertyValue: any): void;
    /** @description Updates a Gantt row. The method expects two parameters - row id and JSON object with the new row data.
    * @param {string | number} rowId. The id of the row.
    * @param {any} data. JSON object with the new row's data. Example: {firstName: 'Peter', lastName: 'Fuller'}.
    */
    updateRow(rowId: string | number, data: any): void;
    /** @description Unselects one or more rows.
    * @param {string | number | (string | number)[]} rowId. The id of the row (or an array of row ids) to unselect.
    */
    unselect(rowId: string | number | (string | number)[]): void;
    readonly isRendered: boolean;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /** @description Add event listeners. */
    private listen;
    /** @description Remove event listeners. */
    private unlisten;
}
